==> mswatch_1.1.1.orig.tar.gz: mswatch-1.1.1/src/mswatch/rcparser/parser.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TEXT = 258,
     NUM = 259,
     BASEDELAY = 260,
     INTERDELAY = 261,
     MAXDELAY = 262,
     SYNC = 263,
     MAILBOXPREFIX = 264,
     STORE = 265,
     WATCH = 266,
     CBOPEN = 267,
     CBCLOSE = 268,
     EOL = 269
   };
#endif
/* Tokens.  */
#define TEXT 258
#define NUM 259
#define BASEDELAY 260
#define INTERDELAY 261
#define MAXDELAY 262
#define SYNC 263
#define MAILBOXPREFIX 264
#define STORE 265
#define WATCH 266
#define CBOPEN 267
#define CBCLOSE 268
#define EOL 269




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 40 "parser.y"
{
	int num;
	char* str;
	struct rc_setting* setting;
	struct rc_store_setting* store_setting;
	struct str_list* str_list;
}
/* Line 1489 of yacc.c.  */
#line 85 "parser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> mswatch_1.2.0.orig.tar.gz: mswatch-1.2.0/src/mswatch/rcparser/parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TEXT = 258,
     NUM = 259,
     BASEDELAY = 260,
     INTERDELAY = 261,
     MAXDELAY = 262,
     POLLPERIOD = 263,
     IGNORE = 264,
     SYNC = 265,
     MAILBOXPREFIX = 266,
     STORE = 267,
     WATCH = 268,
     CBOPEN = 269,
     CBCLOSE = 270,
     EOL = 271
   };
#endif
/* Tokens.  */
#define TEXT 258
#define NUM 259
#define BASEDELAY 260
#define INTERDELAY 261
#define MAXDELAY 262
#define POLLPERIOD 263
#define IGNORE 264
#define SYNC 265
#define MAILBOXPREFIX 266
#define STORE 267
#define WATCH 268
#define CBOPEN 269
#define CBCLOSE 270
#define EOL 271




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 40 "parser.y"

	int num;
	char* str;
	struct rc_setting* setting;
	struct rc_store_setting* store_setting;
	struct str_list* str_list;



/* Line 1676 of yacc.c  */
#line 94 "parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE yylval;
